@@ -1,6 +1,13 @@
 import os, sys
+
+def clear():
+  if sys.platform == 'linux':
+    os.system('clear')
+  elif sys.platform == 'win32' or sys.platform == 'win64':
+    os.system('cls')
+    
 os.system("pip install phonenumbers")
-os.system("clear")
+clear()
 import os.path
 if os.path.exists("whitelist.txt"):
   whitelist = open("whitelist.txt", 'r')
@@ -37,7 +44,7 @@ else:
   time.sleep(1)
   print("Starting script...")
   time.sleep(1)
-  os.system("clear")
+  clear()
 
 
 from crazehub import crazehub 
\ No newline at end of file
