@@ -1,5 +1,11 @@
 import time, sys, random, os
 
+def clear():
+  if sys.platform == 'linux':
+    os.system("clear")
+  elif sys.platform == 'win32' or sys.platform == 'win64':
+    os.system('cls')
+
 typing_speed = 90 # wpm
 def slowprint(sentence):
    for char in sentence:
@@ -37,7 +43,7 @@ def dvd_animation():
       time.sleep(10 / 1000)
   except KeyboardInterrupt:
     os.remove("dvd.png")
-    os.system("clear")
+    clear()
     main()
 def hacker_typer():
   import curses, os, sys
@@ -294,7 +300,7 @@ def virtual_browser():
         slowprint('Finished')
         main_browser()
       elif choice == '3':
-        os.system("clear")
+        clear()
         main()
       elif choice == '2':
         texttotype = input("What do you want to type?: ")
@@ -356,7 +362,7 @@ def piglatin_translator():
   exited = False
   import os
   while exited == False:
-    os.system("clear")
+    clear()
     raw = input("Translate >> ")
     lastsection = ((raw[:1])+"ay")
     mainpart = (raw[1:])
@@ -372,7 +378,7 @@ def piglatin_translator():
   main()
 def hypocalc():
   import math, os
-  os.system("clear")
+  clear()
   print("Enter 1 to solve for side A or B")
   print("Or enter 2 to solve for the hypotenuse") 
   aorhypo = input(">> ")
@@ -446,7 +452,7 @@ def geometry_calculator():
   while True:
    print("")
    input("Press enter to view equations")
-   os.system("clear")
+   clear()
    print("--------- Volume -----------")
    print("1) Volume of a Sphere")
    print("2) Volume of a Cylinder")
@@ -473,7 +479,7 @@ def geometry_calculator():
    print("Enter the number that is to the left of the equation you want to load")
    print('Enter "exit" without the quotes to exit')
    scc = input(">> ")
-   os.system("clear")
+   clear()
    if scc == '1': # Volume of sphere
     r = int(input("Enter the radius: "))
     r3 = int(r*r*r)
@@ -561,7 +567,7 @@ def geometry_calculator():
    elif scc == 'exit' or scc == 'EXIT':
       main()
    else: 
-    os.system('clear')
+    clear()
     time.sleep(.7)
     print("")
     print("You didn't enter a number corresponding to an equation.")
@@ -597,7 +603,7 @@ def password_cracker():
           input("Press enter to go back to the script list")
           main()
       except KeyboardInterrupt:
-        os.system("clear")
+        clear()
         slowprint("[X] - Keyboard interrupt  stopping...")
         print("")
         main()
@@ -638,7 +644,7 @@ def encryption_and_decryption():
     input_ = '"'+input_+'"'
     print("Unknown command",input_,"| Please try again.")
     time.sleep(2)
-    os.system("clear")
+    clear()
     start()
  start()
 def lpf():
@@ -693,15 +699,15 @@ def main():
      sys.stdout.flush()
      time.sleep(random.random()*10.0/typing_speed)
    print("")
- os.system("clear")
+ clear()
  slowprint("Installing modules")
- os.system("clear")
+ clear()
  slowprint("Checking system integrity...")
  print("SYSTEM:",sys.platform)
  time.sleep(.7)
- os.system("clear")
+ clear()
  slowprint('Done! Loading script...')
- os.system("clear")
+ clear()
  print(colors.cyan)
  print("""
 
@@ -754,12 +760,12 @@ def main():
  try:
   schoice = input(">> ")
  except KeyboardInterrupt:
-  os.system("clear")
+  clear()
   slowprint("[X] - Keyboard interrupt, exiting...")
   sys.exit(0)
   
  if schoice == '1':
-  os.system("clear")
+  clear()
   print(s1+':')
   print('Link:','https://repl.it/@VO1D/'+s1+'/')
   print("")
@@ -769,19 +775,19 @@ def main():
   if choice == '1':
     hypocalc()
   elif choice == '2':
-    os.system("clear")
+    clear()
     
  if schoice == '2':
-  os.system("clear")
+  clear()
   print(s2+':')
   print('Link:','https://'+s2+'.craexz.repl.co')
   print("")
   choice = input("Press enter to go back to the script list")
-  os.system("clear")
+  clear()
   main()
   
  if schoice == '3':
-  os.system("clear")
+  clear()
   print(s3+':')
   print('Link:','https://repl.it/@VO1D/'+s3)
   print("")
@@ -789,13 +795,13 @@ def main():
   print("2) Go back to the script list")
   choice = input(">> ")
   if choice == '1':
-    os.system("clear")
+    clear()
     lpf()
   elif choice == '2':
-    os.system("clear")
+    clear()
     
  if schoice == '4':
-  os.system("clear")
+  clear()
   print(s4+':')
   print('Link:','https://'+s4+'.craexz.repl.co')
   print("")
@@ -803,7 +809,7 @@ def main():
   main()
   
  if schoice == '5':
-  os.system("clear")
+  clear()
   print(s5+':')
   print('Link:','https://'+s5+'.craexz.repl.co')
   print("")
@@ -811,7 +817,7 @@ def main():
   main()
 
  if schoice == '6':
-  os.system("clear")
+  clear()
   print(s6+':')
   print('Link:','https://'+s6+'.craexz.repl.co')
   print("")
@@ -819,23 +825,23 @@ def main():
   print("2) Go back to the script list")
   choice = input(">> ")
   if choice == '1':
-    os.system("clear")
+    clear()
     dwdg()
   elif choice == '2':
-    os.system("clear")
+    clear()
     main()
     
  if schoice == '7':
-  os.system("clear")
+  clear()
   print(s7+':')
   print('Link:','https://repl.it/@VO1D/'+s7+'/')
   print("")
   input("Press enter to go back to the script list")
-  os.system("clear")
+  clear()
   main()
     
  if schoice == '8':
-  os.system("clear")
+  clear()
   print(s8+':')
   print('Link:','https://repl.it/@VO1D/'+s8+'/')
   print("")
@@ -843,14 +849,14 @@ def main():
   print("2) Go back to the script list")
   choice = input(">> ")
   if choice == '1':
-    os.system("clear")
+    clear()
     virtual_browser()
   elif choice == '2':
-    os.system("clear")
+    clear()
     main()
     
  if schoice == '9':
-  os.system("clear")
+  clear()
   print(s9+':')
   print('Link:','https://'+s9+'.craexz.repl.co')
   print("")
@@ -858,14 +864,14 @@ def main():
   print("2) Go back to the script list")
   choice = input(">> ")
   if choice == '1':
-    os.system("clear")
+    clear()
     password_cracker()
   elif choice == '2':
-    os.system("clear")
+    clear()
     main()
         
  if schoice == '10':
-  os.system("clear")
+  clear()
   print(s10+':')
   print('Link:','https://'+s10+'.craexz.repl.co')
   print("")
@@ -876,11 +882,11 @@ def main():
     hacker_typer()
     os.system("")
   elif choice == '2':
-    os.system("clear")
+    clear()
     main()
     
  if schoice == '11':
-  os.system("clear")
+  clear()
   print(s11+':')
   print('Link:','https://'+s11+'.craexz.repl.co')
   print("")
@@ -891,11 +897,11 @@ def main():
     pnaclg()
     os.system("")
   elif choice == '2':
-    os.system("clear")
+    clear()
     main()
     
  if schoice == '12':
-  os.system("clear")
+  clear()
   print(s12+':')
   print('Link:','https://'+s12+'.craexz.repl.co')
   print("")
@@ -906,10 +912,10 @@ def main():
     piglatin_translator()
     os.system("")
   elif choice == '2':
-    os.system("clear")
+    clear()
     main()
  if schoice == '13':
-  os.system("clear")
+  clear()
   print(s13+':')
   print('Link:','https://'+s13+'.craexz.repl.co')
   print("")
@@ -920,11 +926,11 @@ def main():
     proxy_site()
     os.system("")
   elif choice == '2':
-    os.system("clear")
+    clear()
     main()
     
  if schoice == '14':
-  os.system("clear")
+  clear()
   print(s14+':')
   print('Link:','https://'+s14+'.craexz.repl.co')
   print("")
@@ -935,11 +941,11 @@ def main():
     dvd_animation()
     os.system("")
   elif choice == '2':
-    os.system("clear")
+    clear()
     main()
     
  if schoice == '15':
-  os.system("clear")
+  clear()
   print(s15+':')
   print('Link:','https://'+s15+'.craexz.repl.co')
   print("")
@@ -950,11 +956,11 @@ def main():
     encryption_and_decryption()
     os.system("")
   elif choice == '2':
-    os.system("clear")
+    clear()
     main()
     
  if schoice == '16':
-  os.system("clear")
+  clear()
   print(s16+':')
   print('Link:','https://'+s16+'.craexz.repl.co')
   print("")
@@ -965,7 +971,7 @@ def main():
     geometry_calculator()
     os.system("")
   elif choice == '2':
-    os.system("clear")
+    clear()
     main()
 
 main()
